==> owncloud-9.0.3.tgz: owncloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "გაზიარება",
    "External Storage" : "ექსტერნალ საცავი",
    "Cron" : "Cron–ი",
    "Log" : "ლოგი",
    "Language changed" : "ენა შეცვლილია",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "Unable to add user to group %s" : "მომხმარებლის დამატება ვერ მოხეხდა ჯგუფში %s",
    "Unable to remove user from group %s" : "მომხმარებლის წაშლა ვერ მოხეხდა ჯგუფიდან %s",
    "Couldn't update app." : "ვერ მოხერხდა აპლიკაციის განახლება.",
    "Email sent" : "იმეილი გაიგზავნა",
    "Email saved" : "იმეილი შენახულია",
    "All" : "ყველა",
    "Please wait...." : "დაიცადეთ....",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "add group" : "ჯგუფის დამატება",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "__language_name__" : "__language_name__",
    "None" : "არა",
    "Login" : "ლოგინი",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "More" : "უფრო მეტი",
    "Less" : "უფრო ნაკლები",
    "Version" : "ვერსია",
    "Forum" : "ფორუმი",
    "Cancel" : "უარყოფა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Password" : "პაროლი",
    "Unable to change your password" : "თქვენი პაროლი არ შეიცვალა",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "Username" : "მომხმარებლის სახელი",
    "Create" : "შექმნა",
    "Default Quota" : "საწყისი ქვოტა",
    "Unlimited" : "ულიმიტო",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/ka_GE.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "ავთენტიფიკაციის შეცდომა",
    "Email sent" : "იმეილი გაიგზავნა",
    "__language_name__" : "__language_name__",
    "Language changed" : "ენა შეცვლილია",
    "Invalid request" : "არასწორი მოთხოვნა",
    "Admins can't remove themself from the admin group" : "ადმინისტრატორებს არ შეუძლიათ საკუთარი თავის წაშლა ადმინ ჯგუფიდან",
    "All" : "ყველა",
    "Please wait...." : "დაიცადეთ....",
    "Disable" : "გამორთვა",
    "Enable" : "ჩართვა",
    "Updating...." : "მიმდინარეობს განახლება....",
    "Error while updating app" : "შეცდომა აპლიკაციის განახლების დროს",
    "Updated" : "განახლებულია",
    "Delete" : "წაშლა",
    "Groups" : "ჯგუფები",
    "undo" : "დაბრუნება",
    "never" : "არასდროს",
    "add group" : "ჯგუფის დამატება",
    "enabled" : "ჩართულია",
    "disabled" : "გათიშულია",
    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
    "A valid password must be provided" : "უნდა მიუთითოთ არსებული პაროლი",
    "Forum" : "ფორუმი",
    "Cron" : "Cron–ი",
    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
    "Sharing" : "გაზიარება",
    "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
    "Allow resharing" : "გადაზიარების დაშვება",
    "Log" : "ლოგი",
    "None" : "არა",
    "Login" : "ლოგინი",
    "Encryption" : "ენკრიპცია",
    "Server address" : "სერვერის მისამართი",
    "Port" : "პორტი",
    "Credentials" : "იუზერ/პაროლი",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP მოდული 'fileinfo' არ არსებობს. ჩვენ გირჩევთ რომ აუცილებლად ჩართოთ ეს მოდული, რომ მიიღოთ კარგი შედეგები mime-type–ს აღმოჩენისას.",
    "Get the apps to sync your files" : "აპლიკაცია ფაილების სინქრონიზაციისთვის",
    "Show First Run Wizard again" : "მაჩვენე თავიდან გაშვებული ვიზარდი",
    "Cancel" : "უარყოფა",
    "Email" : "იმეილი",
    "Your email address" : "თქვენი იმეილ მისამართი",
    "Password" : "პაროლი",
    "Unable to change your password" : "თქვენი პაროლი არ შეიცვალა",
    "Current password" : "მიმდინარე პაროლი",
    "New password" : "ახალი პაროლი",
    "Change password" : "პაროლის შეცვლა",
    "Language" : "ენა",
    "Help translate" : "თარგმნის დახმარება",
    "Unlimited" : "ულიმიტო",
    "Name" : "სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Version" : "ვერსია",
    "Personal" : "პირადი",
    "Admin" : "ადმინისტრატორი",
    "Error" : "შეცდომა",
    "Create" : "შექმნა",
    "Default Quota" : "საწყისი ქვოტა",
    "Other" : "სხვა",
    "Quota" : "ქვოტა",
    "set new password" : "დააყენეთ ახალი პაროლი",
    "Default" : "საწყისი პარამეტრები"
},
"nplurals=1; plural=0;");
